# Part 2: Main program flow

This main program flow is implemented in the `main()` function
of the program which is defined in the file `main.cc` described below. Additionally, we can see how to implement an adaptive grid with a saturation dependent indicator.

The code documentation is structured as follows:

[[_TOC_]]
